@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-app.h 5102 2006-08-16 17:45:13Z pborelli $
+ * $Id: gedit-app.h 6116 2008-01-24 22:15:19Z pborelli $
  */
 
 #ifndef __GEDIT_APP_H__
@@ -42,7 +42,6 @@ G_BEGIN_DECLS
  */
 #define GEDIT_TYPE_APP              (gedit_app_get_type())
 #define GEDIT_APP(obj)              (G_TYPE_CHECK_INSTANCE_CAST((obj), GEDIT_TYPE_APP, GeditApp))
-#define GEDIT_APP_CONST(obj)        (G_TYPE_CHECK_INSTANCE_CAST((obj), GEDIT_TYPE_APP, GeditApp const))
 #define GEDIT_APP_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass), GEDIT_TYPE_APP, GeditAppClass))
 #define GEDIT_IS_APP(obj)           (G_TYPE_CHECK_INSTANCE_TYPE((obj), GEDIT_TYPE_APP))
 #define GEDIT_IS_APP_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GEDIT_TYPE_APP))
@@ -113,9 +112,11 @@ GeditLockdownMask gedit_app_get_lockdown		(GeditApp *app);
  */
 GeditWindow	*_gedit_app_restore_window		(GeditApp    *app,
 							 const gchar *role);
-GeditWindow	*_gedit_app_get_window_in_workspace	(GeditApp  *app,
-							 GdkScreen *screen,
-							 gint       workspace);
+GeditWindow	*_gedit_app_get_window_in_viewport	(GeditApp     *app,
+							 GdkScreen    *screen,
+							 gint          workspace,
+							 gint          viewport_x,
+							 gint          viewport_y);
 void		 _gedit_app_set_lockdown		(GeditApp          *app,
 							 GeditLockdownMask  lockdown);
 void		 _gedit_app_set_lockdown_bit		(GeditApp          *app,
@@ -128,6 +129,13 @@ void		 _gedit_app_set_lockdown_bit		(GeditApp          *app,
 void		 _gedit_window_set_lockdown		(GeditWindow         *window,
 							 GeditLockdownMask    lockdown);
 
+/* global print config */
+GtkPageSetup		*_gedit_app_get_default_page_setup	(GeditApp         *app);
+void			 _gedit_app_set_default_page_setup	(GeditApp         *app,
+								 GtkPageSetup     *page_setup);
+GtkPrintSettings	*_gedit_app_get_default_print_settings	(GeditApp         *app);
+void			 _gedit_app_set_default_print_settings	(GeditApp         *app,
+								 GtkPrintSettings *settings);
 
 G_END_DECLS
 
