@@ -25,22 +25,21 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit.c,v 1.145 2006/12/17 15:41:19 pborelli Exp $
+ * $Id: gedit.c 6426 2008-08-17 19:00:48Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
+#include <errno.h>
 #include <locale.h>
+#include <stdlib.h>
 #include <string.h>
 
 #include <glib/gi18n.h>
 #include <glib/goption.h>
 #include <gdk/gdkx.h>
-#include <libgnome/libgnome.h>
-#include <libgnomeui/libgnomeui.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
 
 #include "gedit-app.h"
 #include "gedit-commands.h"
@@ -54,6 +53,7 @@
 #include "gedit-window.h"
 
 #include "bacon-message-connection.h"
+#include "eggsmclient.h"
 
 static guint32 startup_timestamp = 0;
 static BaconMessageConnection *connection;
@@ -70,7 +70,7 @@ static GSList *file_list = NULL;
 static const GOptionEntry options [] =
 {
 	{ "encoding", '\0', 0, G_OPTION_ARG_STRING, &encoding_charset,
-	  N_("Set the character encoding to be used to open the files listed on the command line"), "ENCODING" /* When out of string freeze, use N_("ENCODING") */ },
+	  N_("Set the character encoding to be used to open the files listed on the command line"), N_("ENCODING")},
 
 	{ "new-window", '\0', 0, G_OPTION_ARG_NONE, &new_window_option,
 	  N_("Create a new toplevel window in an existing instance of gedit"), NULL },
@@ -198,6 +198,8 @@ on_message_received (const char *message,
 	gchar **commands;
 	gchar **params;
 	gint workspace;
+	gint viewport_x;
+	gint viewport_y;
 	gchar *display_name;
 	gint screen_number;
 	gint i;
@@ -213,11 +215,13 @@ on_message_received (const char *message,
 	commands = g_strsplit (message, "\v", -1);
 
 	/* header */
-	params = g_strsplit (commands[0], "\t", 4);
+	params = g_strsplit (commands[0], "\t", 6);
 	startup_timestamp = atoi (params[0]);
 	display_name = params[1];
 	screen_number = atoi (params[2]);
 	workspace = atoi (params[3]);
+	viewport_x = atoi (params[4]);
+	viewport_y = atoi (params[5]);
 
 	display = display_open_if_needed (display_name);
 	if (display == NULL)
@@ -283,9 +287,11 @@ on_message_received (const char *message,
 	else
 	{
 		/* get a window in the current workspace (if exists) and raise it */
-		window = _gedit_app_get_window_in_workspace (app,
-							     screen,
-							     workspace);
+		window = _gedit_app_get_window_in_viewport (app,
+							    screen,
+							    workspace,
+							    viewport_x,
+							    viewport_y);
 	}
 
 	if (file_list != NULL)
@@ -349,11 +355,13 @@ send_bacon_message (void)
 	const gchar *display_name;
 	gint screen_number;
 	gint ws;
+	gint viewport_x;
+	gint viewport_y;
 	GString *command;
 
 	/* the messages have the following format:
-	 * <---                   header                       ---> <----            body             ----->
-	 * timestamp \t display_name \t screen_number \t workspace \v OP1 \t arg \t arg \v OP2 \t arg \t arg|...
+	 * <---                                  header                                     ---> <----            body             ----->
+	 * timestamp \t display_name \t screen_number \t workspace \t viewport_x \t viewport_y \v OP1 \t arg \t arg \v OP2 \t arg \t arg|...
 	 *
 	 * when the arg is a list of uri, they are separated by a space.
 	 * So the delimiters are \v for the commands, \t for the tokens in
@@ -373,16 +381,19 @@ send_bacon_message (void)
 	gedit_debug_message (DEBUG_APP, "Screen: %d", screen_number);	
 
 	ws = gedit_utils_get_current_workspace (screen);
+	gedit_utils_get_current_viewport (screen, &viewport_x, &viewport_y);
 
 	command = g_string_new (NULL);
 
 	/* header */
 	g_string_append_printf (command,
-				"%" G_GUINT32_FORMAT "\t%s\t%d\t%d",
+				"%" G_GUINT32_FORMAT "\t%s\t%d\t%d\t%d\t%d",
 				startup_timestamp,
 				display_name,
 				screen_number,
-				ws);
+				ws,
+				viewport_x,
+				viewport_y);
 
 	/* NEW-WINDOW command */
 	if (new_window_option)
@@ -431,11 +442,15 @@ send_bacon_message (void)
 int
 main (int argc, char *argv[])
 {
-	GnomeProgram *program;
 	GOptionContext *context;
+	GeditPluginsEngine *engine;
 	GeditWindow *window;
 	GeditApp *app;
 	gboolean restored = FALSE;
+	GError *error = NULL;
+
+	/* Init glib threads asap */
+	g_thread_init (NULL);
 
 	/* Setup debugging */
 	gedit_debug_init ();
@@ -449,22 +464,21 @@ main (int argc, char *argv[])
 
 	startup_timestamp = get_startup_timestamp();
 
-	gedit_debug_message (DEBUG_APP, "Run gnome_program_init");
-
 	/* Setup command line options */
 	context = g_option_context_new (_("- Edit text files"));
 	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
-	
-	/* Initialize gnome program */
-	program = gnome_program_init ("gedit", VERSION,
-			    LIBGNOMEUI_MODULE, argc, argv,
-			    GNOME_PARAM_GOPTION_CONTEXT, context,
-			    GNOME_PARAM_HUMAN_READABLE_NAME,
-		            _("Text Editor"),
-			    GNOME_PARAM_APP_DATADIR, DATADIR,
-			    NULL);
+	g_option_context_add_group (context, gtk_get_option_group (FALSE));
+	g_option_context_add_group (context, egg_sm_client_get_option_group ());
 
-	gedit_debug_message (DEBUG_APP, "Done gnome_program_init");
+	gtk_init (&argc, &argv);
+
+	if (!g_option_context_parse (context, &argc, &argv, &error))
+	{
+	        g_print(_("%s\nRun '%s --help' to see a full list of available command line options.\n"),
+			error->message, argv[0]);
+		g_error_free (error);
+		return 1;
+	}
 
 	gedit_debug_message (DEBUG_APP, "Create bacon connection");
 
@@ -499,7 +513,9 @@ main (int argc, char *argv[])
 		}
 	}
 	else
+	{
 		g_warning ("Cannot create the 'gedit' connection.");
+	}
 
 	gedit_debug_message (DEBUG_APP, "Set icon");
 	
@@ -513,19 +529,15 @@ main (int argc, char *argv[])
 	gedit_debug_message (DEBUG_APP, "Init prefs manager");
 	gedit_prefs_manager_app_init ();
 
-	/* Initialize authentication manager */
-	gedit_debug_message (DEBUG_APP, "Init authentication manager");	
-	gnome_authentication_manager_init ();
-	
 	/* Init plugins engine */
-	gedit_debug_message (DEBUG_APP, "Init plugins");	
-	gedit_plugins_engine_init ();
+	gedit_debug_message (DEBUG_APP, "Init plugins");
+	engine = gedit_plugins_engine_get_default ();
 
 	gtk_about_dialog_set_url_hook (gedit_utils_activate_url, NULL, NULL);
 	
 	/* Initialize session management */
 	gedit_debug_message (DEBUG_APP, "Init session manager");		
-	gedit_session_init (argv[0]);
+	gedit_session_init ();
 
 	if (gedit_session_is_restored ())
 		restored = gedit_session_load ();
@@ -575,14 +587,13 @@ main (int argc, char *argv[])
 
 	bacon_message_connection_free (connection);
 
-	gedit_plugins_engine_shutdown ();
+	/* We kept the original engine reference here. So let's unref it to
+	 * finalize it properly. 
+	 */
+	g_object_unref (engine);
 	gedit_prefs_manager_app_shutdown ();
 	gedit_metadata_manager_shutdown ();
 
-	gnome_accelerators_sync ();
-
-	g_object_unref (program);
-
 	return 0;
 }
 
