@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gedit-spell-plugin.c 5814 2007-08-15 15:40:01Z pborelli $
+ * $Id: gedit-spell-plugin.c 6029 2007-12-22 16:14:34Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -32,8 +32,6 @@
 #include <glib/gutils.h>
 #include <gmodule.h>
 
-#include <libgnomeui/gnome-stock-icons.h>
-
 #include <gedit/gedit-debug.h>
 #include <gedit/gedit-metadata-manager.h>
 #include <gedit/gedit-prefs-manager.h>
@@ -47,7 +45,9 @@
 #define WINDOW_DATA_KEY "GeditSpellPluginWindowData"
 #define MENU_PATH "/MenuBar/ToolsMenu/ToolsOps_1"
 
-#define GEDIT_SPELL_PLUGIN_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), GEDIT_TYPE_SPELL_PLUGIN, GeditSpellPluginPrivate))
+#define GEDIT_SPELL_PLUGIN_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), \
+					       GEDIT_TYPE_SPELL_PLUGIN, \
+					       GeditSpellPluginPrivate))
 
 GEDIT_PLUGIN_REGISTER_TYPE(GeditSpellPlugin, gedit_spell_plugin)
 
@@ -68,13 +68,13 @@ static const GtkActionEntry action_entries[] =
 	{ "CheckSpell",
 	  GTK_STOCK_SPELL_CHECK,
 	  N_("_Check Spelling"),
-	  "F7",
+	  "<shift>F7",
 	  N_("Check the current document for incorrect spelling"),
 	  G_CALLBACK (spell_cb)
 	},
 
 	{ "ConfigSpell",
-	  GNOME_STOCK_BOOK_BLUE,
+	  NULL,
 	  N_("Set _Language..."),
 	  NULL,
 	  N_("Set the language of the current document"),
